==> qtjambi-qt3drender-5.15.4-sources.jar: io/qt/qt3d/render/QLayerFilter.java <==
package io.qt.qt3d.render;


/**
 * <p>Controls layers drawn in a frame graph branch</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qt3drender-qlayerfilter.html">Qt3DRender::QLayerFilter</a></p>
 */
public class QLayerFilter extends io.qt.qt3d.render.QFrameGraphNode
{
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QLayerFilter.class);
    
    /**
     * <p>Java wrapper for Qt enum <a href="http://doc.qt.io/qt-5/qt3drender-qlayerfilter.html#FilterMode-enum">Qt3DRender::QLayerFilter::FilterMode</a></p>
     */
    public enum FilterMode implements io.qt.QtEnumerator {
        AcceptAnyMatchingLayers(0),
        AcceptAllMatchingLayers(1),
        DiscardAnyMatchingLayers(2),
        DiscardAllMatchingLayers(3);

        private FilterMode(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static FilterMode resolve(int value) {
            switch (value) {
            case 0: return AcceptAnyMatchingLayers;
            case 1: return AcceptAllMatchingLayers;
            case 2: return DiscardAnyMatchingLayers;
            case 3: return DiscardAllMatchingLayers;
            default: throw new io.qt.QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qlayerfilter.html#filterMode-prop">Qt3DRender::QLayerFilter::filterModeChanged(Qt3DRender::QLayerFilter::FilterMode)</a></p>
     */
    @io.qt.QtPropertyNotify(name="filterMode")
    public final Signal1<io.qt.qt3d.render.QLayerFilter.FilterMode> filterModeChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QLayerFilter(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QLayerFilter() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qlayerfilter.html#QLayerFilter">Qt3DRender::QLayerFilter::QLayerFilter(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QLayerFilter(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QLayerFilter instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qlayerfilter.html#addLayer">Qt3DRender::QLayerFilter::addLayer(Qt3DRender::QLayer*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void addLayer(io.qt.qt3d.render.QLayer layer){
        addLayer_native_Qt3DRender_QLayer_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(layer));
    }
    
    @io.qt.QtUninvokable
    private native void addLayer_native_Qt3DRender_QLayer_ptr(long __this__nativeId, long layer);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode-obsolete.html#createNodeCreationChange">Qt3DCore::QNode::createNodeCreationChange()const</a></p>
     */
    @Deprecated
    @io.qt.QtUninvokable
    protected final io.qt.qt3d.core.QNodeCreatedChange createNodeCreationChange() throws io.qt.QNoImplementationException {
        return createNodeCreationChange_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @Deprecated
    private static io.qt.qt3d.core.QNodeCreatedChange createNodeCreationChange_native_constfct(long __this__nativeId) throws io.qt.QNoImplementationException {
        throw new io.qt.QNoImplementationException();
    }
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qlayerfilter.html#filterMode-prop">Qt3DRender::QLayerFilter::filterMode()const</a></p>
     */
    @io.qt.QtPropertyReader(name="filterMode")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.render.QLayerFilter.FilterMode filterMode(){
        return io.qt.qt3d.render.QLayerFilter.FilterMode.resolve(filterMode_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @io.qt.QtUninvokable
    private native int filterMode_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qlayerfilter.html#layers">Qt3DRender::QLayerFilter::layers()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QVector<io.qt.qt3d.render.QLayer> layers(){
        return layers_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QVector<io.qt.qt3d.render.QLayer> layers_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qlayerfilter.html#removeLayer">Qt3DRender::QLayerFilter::removeLayer(Qt3DRender::QLayer*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void removeLayer(io.qt.qt3d.render.QLayer layer){
        removeLayer_native_Qt3DRender_QLayer_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(layer));
    }
    
    @io.qt.QtUninvokable
    private native void removeLayer_native_Qt3DRender_QLayer_ptr(long __this__nativeId, long layer);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qlayerfilter.html#filterMode-prop">Qt3DRender::QLayerFilter::setFilterMode(Qt3DRender::QLayerFilter::FilterMode)</a></p>
     */
    @io.qt.QtPropertyWriter(name="filterMode")
    @io.qt.QtUninvokable
    public final void setFilterMode(io.qt.qt3d.render.QLayerFilter.FilterMode filterMode){
        setFilterMode_native_Qt3DRender_QLayerFilter_FilterMode(QtJambi_LibraryUtilities.internal.nativeId(this), filterMode.value());
    }
    
    @io.qt.QtUninvokable
    private native void setFilterMode_native_Qt3DRender_QLayerFilter_FilterMode(long __this__nativeId, int filterMode);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QLayerFilter(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QLayerFilter(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QLayerFilter instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3drender-5.15.10-sources.jar: io/qt/qt3d/render/QLayerFilter.java <==
package io.qt.qt3d.render;


/**
 * <p>Controls layers drawn in a frame graph branch</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3drender-qlayerfilter.html">Qt3DRender::QLayerFilter</a></p>
 */
public class QLayerFilter extends io.qt.qt3d.render.QFrameGraphNode
{
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QLayerFilter.class);
    
    /**
     * <p>Java wrapper for Qt enum <a href="http://doc.qt.io/qt-5/qt3drender-qlayerfilter.html#FilterMode-enum">Qt3DRender::QLayerFilter::FilterMode</a></p>
     */
    public enum FilterMode implements io.qt.QtEnumerator {
        AcceptAnyMatchingLayers(0),
        AcceptAllMatchingLayers(1),
        DiscardAnyMatchingLayers(2),
        DiscardAllMatchingLayers(3);

        private FilterMode(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static FilterMode resolve(int value) {
            switch (value) {
            case 0: return AcceptAnyMatchingLayers;
            case 1: return AcceptAllMatchingLayers;
            case 2: return DiscardAnyMatchingLayers;
            case 3: return DiscardAllMatchingLayers;
            default: throw new io.qt.QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qlayerfilter.html#filterMode-prop">Qt3DRender::QLayerFilter::filterModeChanged(Qt3DRender::QLayerFilter::FilterMode)</a></p>
     */
    @io.qt.QtPropertyNotify(name="filterMode")
    public final Signal1<io.qt.qt3d.render.QLayerFilter.FilterMode> filterModeChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QLayerFilter(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QLayerFilter() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qlayerfilter.html#QLayerFilter">Qt3DRender::QLayerFilter::QLayerFilter(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QLayerFilter(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QLayerFilter instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qlayerfilter.html#addLayer">Qt3DRender::QLayerFilter::addLayer(Qt3DRender::QLayer*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void addLayer(io.qt.qt3d.render.QLayer layer){
        addLayer_native_Qt3DRender_QLayer_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(layer));
    }
    
    @io.qt.QtUninvokable
    private native void addLayer_native_Qt3DRender_QLayer_ptr(long __this__nativeId, long layer);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode-obsolete.html#createNodeCreationChange">Qt3DCore::QNode::createNodeCreationChange()const</a></p>
     */
    @Deprecated
    @io.qt.QtUninvokable
    protected final io.qt.qt3d.core.QNodeCreatedChange createNodeCreationChange() throws io.qt.QNoImplementationException {
        return createNodeCreationChange_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @Deprecated
    private static io.qt.qt3d.core.QNodeCreatedChange createNodeCreationChange_native_constfct(long __this__nativeId) throws io.qt.QNoImplementationException {
        throw new io.qt.QNoImplementationException();
    }
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qlayerfilter.html#filterMode-prop">Qt3DRender::QLayerFilter::filterMode()const</a></p>
     */
    @io.qt.QtPropertyReader(name="filterMode")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.render.QLayerFilter.FilterMode filterMode(){
        return io.qt.qt3d.render.QLayerFilter.FilterMode.resolve(filterMode_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @io.qt.QtUninvokable
    private native int filterMode_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qlayerfilter.html#layers">Qt3DRender::QLayerFilter::layers()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QVector<io.qt.qt3d.render.QLayer> layers(){
        return layers_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QVector<io.qt.qt3d.render.QLayer> layers_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qlayerfilter.html#removeLayer">Qt3DRender::QLayerFilter::removeLayer(Qt3DRender::QLayer*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void removeLayer(io.qt.qt3d.render.QLayer layer){
        removeLayer_native_Qt3DRender_QLayer_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(layer));
    }
    
    @io.qt.QtUninvokable
    private native void removeLayer_native_Qt3DRender_QLayer_ptr(long __this__nativeId, long layer);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qlayerfilter.html#filterMode-prop">Qt3DRender::QLayerFilter::setFilterMode(Qt3DRender::QLayerFilter::FilterMode)</a></p>
     */
    @io.qt.QtPropertyWriter(name="filterMode")
    @io.qt.QtUninvokable
    public final void setFilterMode(io.qt.qt3d.render.QLayerFilter.FilterMode filterMode){
        setFilterMode_native_Qt3DRender_QLayerFilter_FilterMode(QtJambi_LibraryUtilities.internal.nativeId(this), filterMode.value());
    }
    
    @io.qt.QtUninvokable
    private native void setFilterMode_native_Qt3DRender_QLayerFilter_FilterMode(long __this__nativeId, int filterMode);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QLayerFilter(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QLayerFilter(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QLayerFilter instance, QDeclarativeConstructor constructor);
    
}
